# Install this package as a python devel alternative.
# PYTHON_VERSION=3.9
# PYTHON_PRIORITY=39
/usr/sbin/alternatives --install /usr/bin/2to3 2to3 /usr/bin/2to3-3.9 39
/usr/sbin/alternatives --install /usr/bin/python3-config python3-config /usr/bin/python3.9-config 39

